.. _user_resources:


Resources
=================


.. _user_resources_presentations-workshops:

Presentations / Workshops
-----------------------------

-   `Slides <https://zenodo.org/record/3265128>`_: from talk at Dataverse Community Meeting 2019
-   `Jupyter Notebook Demo <https://github.com/AUSSDA/pyDataverse_demo_tromso>`_: at European Dataverse Community Workshop Tromso 2020


.. _user_resources_dataverse:

Dataverse Project
-----------------------------

- `Dataverse <https://dataverse.org/>`_
    - `API Guide <https://guides.dataverse.org/en/latest/api/index.html>`_


.. _user_resources_developing:

Developing
-----------------------------

**Helpful**

- `JSON Schema <https://json-schema.org>`_

  - `Validator Webservice <https://jsonschema.net/home>`_
  - `Getting Started <https://json-schema.org/learn/getting-started-step-by-step.html>`_
  - `Schema Validation <https://json-schema.org/draft/2019-09/json-schema-validation.html>`_

**Open Source Development**

- `Producing Open Source Software by Karl Fogel <https://producingoss.com/>`_
- `GitHub flow <https://guides.github.com/introduction/flow/>`_
- `Git Workflow <https://www.atlassian.com/git/workflows>`_
- `Writing on GitHub <https://docs.github.com/en/github/writing-on-github>`_
